Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(312)

Unified Diff: third_party/WebKit/Source/modules/webaudio/PannerNode.cpp

Issue 2103043007: Rename AbstractAudioContext to BaseAudioContext (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Use ASSERT(isGraphOwner()) instead of DCHECK Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webaudio/PannerNode.cpp
diff --git a/third_party/WebKit/Source/modules/webaudio/PannerNode.cpp b/third_party/WebKit/Source/modules/webaudio/PannerNode.cpp
index 44ccd79bcc05a664090b230599995d2bc951e867..5f4d35fe4cae10eafbbf739aa36a2ca1ed32ad48 100644
--- a/third_party/WebKit/Source/modules/webaudio/PannerNode.cpp
+++ b/third_party/WebKit/Source/modules/webaudio/PannerNode.cpp
@@ -27,10 +27,10 @@
#include "bindings/core/v8/ExceptionState.h"
#include "core/dom/ExceptionCode.h"
#include "core/dom/ExecutionContext.h"
-#include "modules/webaudio/AbstractAudioContext.h"
#include "modules/webaudio/AudioBufferSourceNode.h"
#include "modules/webaudio/AudioNodeInput.h"
#include "modules/webaudio/AudioNodeOutput.h"
+#include "modules/webaudio/BaseAudioContext.h"
#include "platform/Histogram.h"
#include "platform/audio/HRTFPanner.h"
#include "wtf/MathExtras.h"
@@ -134,7 +134,7 @@ void PannerHandler::process(size_t framesToProcess)
// HRTFDatabase should be loaded before proceeding when the panning model is HRTF.
if (m_panningModel == Panner::PanningModelHRTF && !listener()->isHRTFDatabaseLoaded()) {
if (context()->hasRealtimeConstraint()) {
// Some AbstractAudioContexts cannot block on the HRTFDatabase loader.
destination->zero();
return;
}
@@ -563,7 +563,7 @@ void PannerHandler::markPannerAsDirty(unsigned dirty)
void PannerHandler::setChannelCount(unsigned long channelCount, ExceptionState& exceptionState)
{
ASSERT(isMainThread());
- AbstractAudioContext::AutoLocker locker(context());
+ BaseAudioContext::AutoLocker locker(context());
// A PannerNode only supports 1 or 2 channels
if (channelCount > 0 && channelCount <= 2) {
@@ -588,7 +588,7 @@ void PannerHandler::setChannelCount(unsigned long channelCount, ExceptionState&
void PannerHandler::setChannelCountMode(const String& mode, ExceptionState& exceptionState)
{
ASSERT(isMainThread());
- AbstractAudioContext::AutoLocker locker(context());
+ BaseAudioContext::AutoLocker locker(context());
ChannelCountMode oldMode = m_channelCountMode;
@@ -640,7 +640,7 @@ void PannerHandler::updateDirtyState()
}
// ----------------------------------------------------------------
-PannerNode::PannerNode(AbstractAudioContext& context)
+PannerNode::PannerNode(BaseAudioContext& context)
: AudioNode(context)
, m_positionX(AudioParam::create(context, ParamTypePannerPositionX, 0.0))
, m_positionY(AudioParam::create(context, ParamTypePannerPositionY, 0.0))
@@ -660,7 +660,7 @@ PannerNode::PannerNode(AbstractAudioContext& context)
m_orientationZ->handler()));
}
-PannerNode* PannerNode::create(AbstractAudioContext& context, ExceptionState& exceptionState)
+PannerNode* PannerNode::create(BaseAudioContext& context, ExceptionState& exceptionState)
{
DCHECK(isMainThread());
« no previous file with comments | « third_party/WebKit/Source/modules/webaudio/PannerNode.h ('k') | third_party/WebKit/Source/modules/webaudio/PeriodicWave.h » ('j') | no next file with comments »
@@ -134,7 +134,7 @@ void PannerHandler::process(size_t framesToProcess)
if (m_panningModel == Panner::PanningModelHRTF && !listener()->isHRTFDatabaseLoaded()) {
if (context()->hasRealtimeConstraint()) {
- // Some AbstractAudioContexts cannot block on the HRTFDatabase loader.
+ // Some BaseAudioContexts cannot block on the HRTFDatabase loader.
destination->zero();
return;

Powered by Google App Engine
This is Rietveld 408576698